# Changelog

All notable changes to `lambda-dom` will be documented in this file. The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Fixed

- Removed obsolete `package-lock.json` file in favor of `yarn.lock`.

## [2.1.0] (2021-08-08)

### Added
- function `preventDefault`

## [2.0.2] (2021-04-28)

### Added

- Provides option for non-minified UMD bundles.

## [2.0.1] (2021-04-28)

### Fixed

- ES2015 syntax in UMD bundle. By adding the `target: "es5"` setting to the webpack config UMD bundles are now
compatible with ES5 environments.

### Changed

- Major improvement to UMD bundle size by letting Typescript default to ES2015 module output.

### Added

- `"exports"` field in package.json, defining the available exports from the package.
- Added UMD file pointers for CDN services to package.json.

## [2.0.0] (2021-04-16)

### BREAKING CHANGES

- Minimal typescript version is now 4.2 due to the dependency to [typed-query-selector](https://github.com/g-plane/typed-query-selector).
- Renamed `queryWithin` to `queryAllWithin`

### Added

- function `innerText`
- function `innerHTML`
- function `queryOne`
- function `queryOneWithin`

### Changed

- Added type-level CSS selector parsing to all functions that query the DOM with given selectors ([PR](https://github.com/JJWesterkamp/lambda-dom/pull/5))

  **affects:**
  - `queryAll`
  - `queryWithin`
  - `touchAll`
  - `touchAllP`
  - `touchElement`
  - `touchElementP`

## [1.3.1] (2021-04-05)

### Fixed

- Exclude local error log from published packages

## [1.3.0] (2021-04-05)

### Added

- function `displayUsing`
- function `showUsing`
- type `StylableElement`
- type `CssdisplayValue`

### Changed

- Changed `string | null` types for `style.display` values in CSS display functions to `CssDisplayValue` to
  provide an autocompletion list of the most commonly used display values.

  **Affects:**
  - `display`
  - `displayIf`
  - `displayUsing` (new)


- Loosened `HTMLElement` type constraints to `ElementCSSInlineStyle` (aliased as `StylableElement`) for
  CSS style related functions. This allows for usage of these functions with other supported elements as well,
  such as SVG elements.

  **Affects:**
  - `display`
  - `show`
  - `hide`
  - `displayIf`
  - `showIf`
  - `style`
  - `displayUsing` (new)
  - `showUsing` (new)


- Loosened `HTMLElement` type constraints to `HTMLOrSVGElement` for dataset functions to allow usage of these
  functions with SVG elements as well.

  **Affects:**
  - `readDataset`
  - `writeDataset`

## [1.2.0] (2021-04-03)

### Added

- function `queryWithin`
- function `remove`
- function `showIf`
- function `displayIf`

## [1.1.2] (2021-04-02)

This version only updates the README with function descriptions.

## [1.1.1] (2021-04-02)

### Changed

- Minor internal refactoring that only improves the declaration file.
- Cleans up the contents of published packages, omitting unneeded files.

## [1.1.0] (2021-04-02)

### Added

- promise factory `DOMReadyP`
- function `onDOMReady`
- promise factory `windowLoadP`
- function `onWindowLoad`

## [1.0.1] (2020-11-19)

This is merely a documentation update.

## [1.0.0] (2020-11-17)

### Added

- Autogenerated HTML documentation [hosted here][docs].

### Changed

- Updated function signatures to include all type info in the initial declarations.
- Updated & improved ts docs.

## [1.0.0-beta1] (2020-11-17, initial release)

### Added

- function `addClasses`
- function `addClassesForMS`
- function `addClassesForNFrames`
- function `deferFrames`
- function `deferFramesP`
- function `display`
- function `getMeta`
- function `hide`
- function `queryAll`
- function `readDataset`
- function `removeClasses`
- function `removeClassesForMS`
- function `removeClassesForNFrames`
- function `setMeta`
- function `show`
- function `style`
- function `toggleClasses`
- function `touchAll`
- function `touchAllP`
- function `touchElement`
- function `touchElementP`
- function `writeDataset`


[docs]: https://jjwesterkamp.github.io/lambda-dom/

[Unreleased]: https://github.com/JJWesterkamp/lambda-dom/compare/v2.1.0...HEAD
[2.1.0]: https://github.com/JJWesterkamp/lambda-dom/compare/v2.0.2...v2.1.0
[2.0.2]: https://github.com/JJWesterkamp/lambda-dom/compare/v2.0.1...v2.0.2
[2.0.1]: https://github.com/JJWesterkamp/lambda-dom/compare/v2.0.0...v2.0.1
[2.0.0]: https://github.com/JJWesterkamp/lambda-dom/compare/v1.3.1...v2.0.0
[1.3.1]: https://github.com/JJWesterkamp/lambda-dom/compare/v1.3.0...v1.3.1
[1.3.0]: https://github.com/JJWesterkamp/lambda-dom/compare/v1.2.0...v1.3.0
[1.2.0]: https://github.com/JJWesterkamp/lambda-dom/compare/v1.1.2...v1.2.0
[1.1.2]: https://github.com/JJWesterkamp/lambda-dom/compare/v1.1.1...v1.1.2
[1.1.1]: https://github.com/JJWesterkamp/lambda-dom/compare/v1.1.0...v1.1.1
[1.1.0]: https://github.com/JJWesterkamp/lambda-dom/compare/v1.0.1...v1.1.0
[1.0.1]: https://github.com/JJWesterkamp/lambda-dom/compare/v1.0.0...v1.0.1
[1.0.0]: https://github.com/JJWesterkamp/lambda-dom/compare/v1.0.0-beta1...v1.0.0
[1.0.0-beta1]: https://github.com/JJWesterkamp/lambda-dom/tree/v1.0.0-beta1
