"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ifElse = void 0;
/**
 * Takes a predicate function, an `onTrue` function and an `onFalse` function, and returns a function that
 * takes an argument, and either applies `onTrue` or `onFalse` to the argument based on the result of
 * applying `pred` to the argument.
 *
 * @param {(x: T) => boolean} pred
 * @param {(x: T) => U} onTrue
 * @param {(x: T) => V} onFalse
 * @return {(x: T) => (U | V)}
 */
function ifElse(pred, onTrue, onFalse) {
    return function (value) { return pred(value) ? onTrue(value) : onFalse(value); };
}
exports.ifElse = ifElse;
