"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addClassesForMS = void 0;
var addClasses_1 = require("./addClasses");
var removeClasses_1 = require("./removeClasses");
/**
 * Adds classes to an element for a given amount of milliseconds.
 *
 * @param ms The amount of milliseconds to add the classes for
 * @param classes Rest parameter for one or multiple classes to temporarily add
 * @param element The element to add the classes to
 *
 * @example
 *
 * ```typescript
 * declare const element: Element
 * addClassesForMS(500, 'class-a', 'class-b') (element)
 * ```
 */
function addClassesForMS(ms) {
    var classes = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        classes[_i - 1] = arguments[_i];
    }
    return function (element) {
        addClasses_1.addClasses.apply(void 0, classes)(element);
        setTimeout(function () { return removeClasses_1.removeClasses.apply(void 0, classes)(element); }, ms);
    };
}
exports.addClassesForMS = addClassesForMS;
