"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deferFramesP = void 0;
var deferFrames_1 = require("./deferFrames");
/**
 * Returns a `Promise<void>` that resolves after `n` animation frames have passed.
 * Like {@linkcode deferFrames} but 'portable', so that many callbacks can subscribe
 * to the 'event' of `n` frames having passed.
 *
 * @param n The amount of animation frames to wait before the returned promise resolves.
 *
 * @example
 *
 * ```typescript
 * async function f() {
 *      // Do something immediately...
 *      await deferFramesP(10)
 *      // Do something else after 10 animation frames:
 * }
 * ```
 */
function deferFramesP(n) {
    return new Promise(function (resolve) { return deferFrames_1.deferFrames(n, resolve); });
}
exports.deferFramesP = deferFramesP;
