"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.displayUsing = void 0;
var display_1 = require("./display");
var hide_1 = require("./hide");
var _tools_1 = require("./_tools");
/**
 * Takes a predicate function for elements and a {@link CssDisplayValue CSS display value}, and returns
 * a function that takes elements. The returned function will set `style.display` onto given elements to either
 * given value or to `'none'` based on the result of applying the predicate to those elements.
 *
 * @example
 * ```typescript
 * declare const checkboxes: HTMLInputElement[]
 * const isChecked = (checkbox: HTMLInputElement) => checkbox.checked
 *
 * // Sets display: 'flex' to all checkboxes that are checked
 * // Sets display: 'none' to all other checkboxes.
 * checkboxes.forEach(displayUsing(isChecked, 'flex'))
 *
 * // This is equivalent to following usage of displayIf():
 * checkboxes.forEach((checkbox) => displayIf(isChecked(checkbox), 'flex')(checkbox))
 * ```
 *
 * @param {(element: T) => boolean} pred
 * @param {string | null} displayValue
 * @return {(element: T) => void}
 */
function displayUsing(pred, displayValue) {
    return _tools_1.ifElse(pred, display_1.display(displayValue), hide_1.hide);
}
exports.displayUsing = displayUsing;
