"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.hide = void 0;
var display_1 = require("./display");
/**
 * Hide the given element through the style.display property.
 * This is a specialisation of {@link display display()} that always sets display to `'none'`.
 *
 * @param element The element to hide.
 * @example
 *
 * ```typescript
 * declare const someElement: Element
 *
 * // Hides the given element
 * hide(someElement)
 *
 * // This is equivalent to:
 * display('none') (someElement)
 * ```
 */
function hide(element) {
    display_1.display('none')(element);
}
exports.hide = hide;
