"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.innerHTML = void 0;
/**
 * Takes an HTML string or `null`, and returns a function that takes `Element` objects. Sets `innerHTML` of
 * given elements to the given string, or to an empty string if given `null`.
 *
 * @example
 * ```typescript
 * // to set inner HTML
 * innerHTML('<span>foo</span>')(element)
 *
 * // to clear inner HTML
 * innerHTML(null)(element)
 *
 * // batch-clear contents:
 * declare const elements: Element[]
 * elements.forEach(innerHTML(null))
 * ```
 */
function innerHTML(html) {
    return function (element) {
        element.innerHTML = html || '';
    };
}
exports.innerHTML = innerHTML;
