"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeClassesForMS = void 0;
var addClasses_1 = require("./addClasses");
var removeClasses_1 = require("./removeClasses");
/**
 * Removes classes from an element for a given amount of milliseconds.
 *
 * @param ms The amount of milliseconds to remove the classes for.
 * @param classes Rest parameter for one or multiple classes to remove.
 * @param element The element to remove the classes from.
 *
 * @example
 * ```typescript
 * declare const element: Element
 * removeClassesForMS(500, 'class-a', 'class-b') (element)
 * ```
 */
function removeClassesForMS(ms) {
    var classes = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        classes[_i - 1] = arguments[_i];
    }
    return function (element) {
        removeClasses_1.removeClasses.apply(void 0, classes)(element);
        window.setTimeout(function () { return addClasses_1.addClasses.apply(void 0, classes)(element); }, ms);
    };
}
exports.removeClassesForMS = removeClassesForMS;
