"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeClassesForNFrames = void 0;
var addClasses_1 = require("./addClasses");
var deferFrames_1 = require("./deferFrames");
var removeClasses_1 = require("./removeClasses");
/**
 * Removes classes from an element for a given amount of animation frames.
 *
 * @param n The amount of animation frames to remove the classes for.
 * @param classes Rest parameter for one or multiple classes to temporarily remove.
 * @param element The element to remove the classes from.
 *
 * @example
 *
 * ```typescript
 * declare const element: Element
 * removeClassesForNFrames(10, 'class-a', 'class-b') (element)
 * ```
 */
function removeClassesForNFrames(n) {
    var classes = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        classes[_i - 1] = arguments[_i];
    }
    return function (element) {
        removeClasses_1.removeClasses.apply(void 0, classes)(element);
        deferFrames_1.deferFrames(n, function () { return addClasses_1.addClasses.apply(void 0, classes)(element); });
    };
}
exports.removeClassesForNFrames = removeClassesForNFrames;
