"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.showUsing = void 0;
var _tools_1 = require("./_tools");
var show_1 = require("./show");
var hide_1 = require("./hide");
/**
 * Takes a predicate function for elements and returns a function that takes elements
 * to conditionally show depending on the result of applying the predicate function to given elements.
 *
 * **Note**
 *
 * This function assumes that given elements are shown by default - ie. there's no CSS rule that has
 * set the element's display to 'none'.
 *
 * @example
 * ```typescript
 * declare const checkboxes: HTMLInputElement[]
 * const isChecked = (input: HTMLInputElement) => input.checked
 *
 * // Unsets inline display of all checkboxes that are checked
 * // Sets display: 'none' to all other checkboxes.
 * checkboxes.forEach(showUsing(isChecked))
 *
 * // This is equivalent to following usage of showIf():
 * checkboxes.forEach((checkbox) => showIf(isChecked(checkbox))(checkbox))
 * ```
 *
 * @param {(element: T) => boolean} pred
 * @return {(element: T) => void}
 */
function showUsing(pred) {
    return _tools_1.ifElse(pred, show_1.show, hide_1.hide);
}
exports.showUsing = showUsing;
