import { addClasses } from './addClasses';
import { deferFrames } from './deferFrames';
import { removeClasses } from './removeClasses';
/**
 * Removes classes from an element for a given amount of animation frames.
 *
 * @param n The amount of animation frames to remove the classes for.
 * @param classes Rest parameter for one or multiple classes to temporarily remove.
 * @param element The element to remove the classes from.
 *
 * @example
 *
 * ```typescript
 * declare const element: Element
 * removeClassesForNFrames(10, 'class-a', 'class-b') (element)
 * ```
 */
export function removeClassesForNFrames(n) {
    var classes = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        classes[_i - 1] = arguments[_i];
    }
    return function (element) {
        removeClasses.apply(void 0, classes)(element);
        deferFrames(n, function () { return addClasses.apply(void 0, classes)(element); });
    };
}
