/*!
 * lambda-dom
 * https://jjwesterkamp.github.io/lambda-dom
 * (c) 2021 Jeffrey Westerkamp
 * This software may be freely distributed under the MIT license.
 */
(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory();
	else if(typeof define === 'function' && define.amd)
		define([], factory);
	else if(typeof exports === 'object')
		exports["LD"] = factory();
	else
		root["LD"] = factory();
})(self, function() {
return /******/ (function() { // webpackBootstrap
/******/ 	"use strict";
/******/ 	// The require scope
/******/ 	var __webpack_require__ = {};
/******/ 	
/************************************************************************/
/******/ 	/* webpack/runtime/define property getters */
/******/ 	!function() {
/******/ 		// define getter functions for harmony exports
/******/ 		__webpack_require__.d = function(exports, definition) {
/******/ 			for(var key in definition) {
/******/ 				if(__webpack_require__.o(definition, key) && !__webpack_require__.o(exports, key)) {
/******/ 					Object.defineProperty(exports, key, { enumerable: true, get: definition[key] });
/******/ 				}
/******/ 			}
/******/ 		};
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/hasOwnProperty shorthand */
/******/ 	!function() {
/******/ 		__webpack_require__.o = function(obj, prop) { return Object.prototype.hasOwnProperty.call(obj, prop); }
/******/ 	}();
/******/ 	
/******/ 	/* webpack/runtime/make namespace object */
/******/ 	!function() {
/******/ 		// define __esModule on exports
/******/ 		__webpack_require__.r = function(exports) {
/******/ 			if(typeof Symbol !== 'undefined' && Symbol.toStringTag) {
/******/ 				Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });
/******/ 			}
/******/ 			Object.defineProperty(exports, '__esModule', { value: true });
/******/ 		};
/******/ 	}();
/******/ 	
/************************************************************************/
var __webpack_exports__ = {};
// ESM COMPAT FLAG
__webpack_require__.r(__webpack_exports__);

// EXPORTS
__webpack_require__.d(__webpack_exports__, {
  "DOMReadyP": function() { return /* reexport */ DOMReadyP; },
  "addClasses": function() { return /* reexport */ addClasses; },
  "addClassesForMS": function() { return /* reexport */ addClassesForMS; },
  "addClassesForNFrames": function() { return /* reexport */ addClassesForNFrames; },
  "deferFrames": function() { return /* reexport */ deferFrames; },
  "deferFramesP": function() { return /* reexport */ deferFramesP; },
  "display": function() { return /* reexport */ display; },
  "displayIf": function() { return /* reexport */ displayIf; },
  "displayUsing": function() { return /* reexport */ displayUsing; },
  "getMeta": function() { return /* reexport */ getMeta; },
  "hide": function() { return /* reexport */ hide; },
  "innerHTML": function() { return /* reexport */ innerHTML; },
  "innerText": function() { return /* reexport */ innerText; },
  "onDOMReady": function() { return /* reexport */ onDOMReady; },
  "onWindowLoad": function() { return /* reexport */ onWindowLoad; },
  "preventDefault": function() { return /* reexport */ preventDefault; },
  "queryAll": function() { return /* reexport */ queryAll; },
  "queryAllWithin": function() { return /* reexport */ queryAllWithin; },
  "queryOne": function() { return /* reexport */ queryOne; },
  "queryOneWithin": function() { return /* reexport */ queryOneWithin; },
  "readDataset": function() { return /* reexport */ readDataset; },
  "remove": function() { return /* reexport */ remove; },
  "removeClasses": function() { return /* reexport */ removeClasses; },
  "removeClassesForMS": function() { return /* reexport */ removeClassesForMS; },
  "removeClassesForNFrames": function() { return /* reexport */ removeClassesForNFrames; },
  "setMeta": function() { return /* reexport */ setMeta; },
  "show": function() { return /* reexport */ show; },
  "showIf": function() { return /* reexport */ showIf; },
  "showUsing": function() { return /* reexport */ showUsing; },
  "style": function() { return /* reexport */ style; },
  "toggleClasses": function() { return /* reexport */ toggleClasses; },
  "touchAll": function() { return /* reexport */ touchAll; },
  "touchAllP": function() { return /* reexport */ touchAllP; },
  "touchElement": function() { return /* reexport */ touchElement; },
  "touchElementP": function() { return /* reexport */ touchElementP; },
  "windowLoadP": function() { return /* reexport */ windowLoadP; },
  "writeDataset": function() { return /* reexport */ writeDataset; }
});

;// CONCATENATED MODULE: ./src/toggleClasses.ts
/**
 * Curried function that first takes a list of classes, then returns a new function that
 * takes the element on which to toggle those classes. The second function optionally takes
 * the second argument `force: boolean` to use on the native `DOMTokenList.toggle()` method.
 * Note that the value for `force` will be the same for all classes that are toggled.
 *
 * @param classes One or multiple classes to toggle.
 * @param element An element onto which to toggle provided classes.
 * @param force The optional boolean for force adding / removing the classes (like the native [`DOMTokenList.toggle`](https://developer.mozilla.org/en-US/docs/Web/API/DOMTokenList/toggle))
 *
 * @example
 *
 * ```typescript
 * declare const someElement: Element
 * declare const elements: Element[]
 *
 * // You can either partially apply toggleClasses:
 * const toggleTwoClasses = toggleClasses('class-one', 'class-two')
 * elements.forEach(toggleTwoClasses)
 *
 * // Or execute toggleClasses in one go:
 * toggleClasses('class-one', 'class-two', '...') (someElement)
 * // Equivalently
 * toggleClasses('class-one', 'class-two', '...') (someElement, undefined)
 *
 * // This is like addClasses:
 * toggleClasses('class-one', 'class-two', '...') (someElement, true)
 *
 * // This is like removeClasses:
 * toggleClasses('class-one', 'class-two', '...') (someElement, false)
 * ```
 */
function toggleClasses() {
    var classes = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        classes[_i] = arguments[_i];
    }
    return function (element, force) { return classes.forEach(function (className) { return element.classList.toggle(className, force); }); };
}

;// CONCATENATED MODULE: ./src/addClasses.ts

/**
 * Curried function that first takes a list of classes, then returns a new function that
 * takes the element to add those classes to.
 *
 * @param classes Rest parameter for one or multiple classes to add.
 * @param element The element to add the classes to.
 *
 * @example
 * ```typescript
 * declare const elements: Element[]
 * declare const someElement: Element
 *
 * // You can either partially apply addClasses to re-use it:
 * const addTwoClasses = addClasses('class-one', 'class-two')
 *
 * elements.forEach(addTwoClasses)
 *
 * // Or execute addClasses in one go:
 * addClasses('class-one', 'class-two') (someElement)
 * ```
 */
function addClasses() {
    var classes = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        classes[_i] = arguments[_i];
    }
    return function (element) { return toggleClasses.apply(void 0, classes)(element, true); };
}

;// CONCATENATED MODULE: ./src/removeClasses.ts

/**
 * Curried function that first takes a list of classes, then returns a new function that
 * takes the element to remove those classes from.
 *
 * @param classes Rest parameter for one or multiple classes to remove.
 * @param element The element to remove the classes from.
 *
 * @example
 *
 * ```typescript
 * declare const someElement: Element
 * declare const elements: Element[]
 *
 * // You can either partially apply removeClasses:
 * const removeTwoClasses = removeClasses('class-one', 'class-two')
 * elements.forEach(removeTwoClasses)
 *
 * // Or execute removeClasses in one go:
 * removeClasses('class-one', 'class-two', 'even-more-classes')(element)
 * ```
 */
function removeClasses() {
    var classes = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        classes[_i] = arguments[_i];
    }
    return function (element) { return toggleClasses.apply(void 0, classes)(element, false); };
}

;// CONCATENATED MODULE: ./src/addClassesForMS.ts


/**
 * Adds classes to an element for a given amount of milliseconds.
 *
 * @param ms The amount of milliseconds to add the classes for
 * @param classes Rest parameter for one or multiple classes to temporarily add
 * @param element The element to add the classes to
 *
 * @example
 *
 * ```typescript
 * declare const element: Element
 * addClassesForMS(500, 'class-a', 'class-b') (element)
 * ```
 */
function addClassesForMS(ms) {
    var classes = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        classes[_i - 1] = arguments[_i];
    }
    return function (element) {
        addClasses.apply(void 0, classes)(element);
        setTimeout(function () { return removeClasses.apply(void 0, classes)(element); }, ms);
    };
}

;// CONCATENATED MODULE: ./src/deferFrames.ts
/**
 * Takes a positive (>= 0) integer `n` and a callback function, and executes the callback function after `n`
 * animation frames have passed.
 *
 * @param n The amount of animation frames to wait.
 * @param handler The callback function to run after `n` animation-frames have passed.
 *
 * @Todo Add the possibility to cancel. The requires the request ID of the latest request.
 *
 * @example
 *
 * ```typescript
 * declare const f: () => void
 * // Run `f` after ten animation frames
 * deferFrames(10, f)
 *
 * // The following 2 statements are equivalent:
 * deferFrames(0, f)
 * requestAnimationFrame(f)
 *
 * // And the following 2 statements are equivalent:
 * deferFrames(1, f)
 * requestAnimationFrame(() => requestAnimationFrame(f))
 *
 * // Etc..
 * ```
 */
function deferFrames(n, handler) {
    n = Math.max(0, n);
    n === 0 ? requestAnimationFrame(handler) : deferFrames(n - 1, function () { return requestAnimationFrame(handler); });
}

;// CONCATENATED MODULE: ./src/addClassesForNFrames.ts



/**
 * Adds classes to an element for a given amount of animation frames.
 *
 * @param n The amount of animation frames to add the classes for.
 * @param classes Rest parameter for one or multiple classes to temporarily add.
 * @param element The element to add the classes to.
 *
 * @example
 *
 * ```typescript
 * declare const element: Element
 * addClassesForNFrames(10, 'class-a', 'class-b') (element)
 * ```
 */
function addClassesForNFrames(n) {
    var classes = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        classes[_i - 1] = arguments[_i];
    }
    return function (element) {
        addClasses.apply(void 0, classes)(element);
        deferFrames(n, function () { return removeClasses.apply(void 0, classes)(element); });
    };
}

;// CONCATENATED MODULE: ./src/deferFramesP.ts

/**
 * Returns a `Promise<void>` that resolves after `n` animation frames have passed.
 * Like {@linkcode deferFrames} but 'portable', so that many callbacks can subscribe
 * to the 'event' of `n` frames having passed.
 *
 * @param n The amount of animation frames to wait before the returned promise resolves.
 *
 * @example
 *
 * ```typescript
 * async function f() {
 *      // Do something immediately...
 *      await deferFramesP(10)
 *      // Do something else after 10 animation frames:
 * }
 * ```
 */
function deferFramesP(n) {
    return new Promise(function (resolve) { return deferFrames(n, resolve); });
}

;// CONCATENATED MODULE: ./src/style.ts
/**
 * Takes an object of style attribute values, and returns a new function that takes an
 * element to apply those styles to.
 *
 * @example
 *
 * ```typescript
 * declare const someElement: HTMLElement
 * style({ color: 'red' }) (someElement)
 *
 * // Or partially apply to re-use the style set:
 * const warningButtonStyle = style({
 *     color: 'red',
 *     backgroundColor: 'white',
 *     border: '1px solid red',
 * })
 *
 * declare const elements: HTMLElement[]
 * elements.forEach(warningButtonStyle)
 * ```
 *
 * @param styles An object with inline styles to set.
 * @param element An element to apply the inline styles to.
 */
function style(styles) {
    return function (element) { return Object.assign(element.style, styles); };
}

;// CONCATENATED MODULE: ./src/display.ts

/**
 * Takes a {@link CssDisplayValue CSS display value} and returns a function that takes
 * {@link StylableElement elements}. When applied to an element the returned function
 * assigns the given display value to the given element's `style.display` property.
 *
 * @param value The display CSS value to use. When `null` any inline display value is removed.
 * @param element The target element to set the display value on.
 *
 * @example
 * ```typescript
 * declare const someElement: Element
 *
 * // This will unset any inline style for `display` and let CSS take over control
 * display(null) (someElement)
 *
 * // This will explicitly set the display property to 'flex'
 * display('flex') (someElement)
 *
 * // and this will hide the element
 * display('none') (someElement)
 *
 * // You can store the display strategies in advance:
 * const hideFn = display('none')
 * const showFn = display('grid')
 *
 * // And then use them on any element conditionally:
 * declare const shouldShow: boolean
 * (shouldShow ? showFn : hideFn) (someElement)
 * ```
 */
function display(value) {
    return style({ display: value || '' });
}

;// CONCATENATED MODULE: ./src/hide.ts

/**
 * Hide the given element through the style.display property.
 * This is a specialisation of {@link display display()} that always sets display to `'none'`.
 *
 * @param element The element to hide.
 * @example
 *
 * ```typescript
 * declare const someElement: Element
 *
 * // Hides the given element
 * hide(someElement)
 *
 * // This is equivalent to:
 * display('none') (someElement)
 * ```
 */
function hide(element) {
    display('none')(element);
}

;// CONCATENATED MODULE: ./src/displayIf.ts


/**
 * Takes a `boolean` condition and a {@link CssDisplayValue CSS display value}, and returns a function
 * that takes elements. The returned function will set `style.display` onto given elements to either given
 * value or to `'none'` based on the given `cond` boolean.
 *
 * Note that the condition is constant for all future calls to the returned function.
 * See {@link displayUsing displayUsing()} for cases where the boolean condition should
 * be determined for each element individually.
 *
 * @example
 * ```typescript
 * declare const checkboxes: HTMLInputElement[]
 * declare const myCondition: boolean
 *
 * // Sets display: 'flex' to all checkboxes if myCondition is true
 * // Sets display: 'none' to all checkboxes otherwise
 * checkboxes.forEach(displayIf(myCondition, 'flex'))
 * ```
 *
 * @param cond         The condition for showing elements
 * @param displayValue The `style.display` value to use
 * @return {(element: T) => void}
 */
function displayIf(cond, displayValue) {
    return cond ? display(displayValue) : hide;
}

;// CONCATENATED MODULE: ./src/_tools.ts
/**
 * Takes a predicate function, an `onTrue` function and an `onFalse` function, and returns a function that
 * takes an argument, and either applies `onTrue` or `onFalse` to the argument based on the result of
 * applying `pred` to the argument.
 *
 * @param {(x: T) => boolean} pred
 * @param {(x: T) => U} onTrue
 * @param {(x: T) => V} onFalse
 * @return {(x: T) => (U | V)}
 */
function ifElse(pred, onTrue, onFalse) {
    return function (value) { return pred(value) ? onTrue(value) : onFalse(value); };
}

;// CONCATENATED MODULE: ./src/displayUsing.ts



/**
 * Takes a predicate function for elements and a {@link CssDisplayValue CSS display value}, and returns
 * a function that takes elements. The returned function will set `style.display` onto given elements to either
 * given value or to `'none'` based on the result of applying the predicate to those elements.
 *
 * @example
 * ```typescript
 * declare const checkboxes: HTMLInputElement[]
 * const isChecked = (checkbox: HTMLInputElement) => checkbox.checked
 *
 * // Sets display: 'flex' to all checkboxes that are checked
 * // Sets display: 'none' to all other checkboxes.
 * checkboxes.forEach(displayUsing(isChecked, 'flex'))
 *
 * // This is equivalent to following usage of displayIf():
 * checkboxes.forEach((checkbox) => displayIf(isChecked(checkbox), 'flex')(checkbox))
 * ```
 *
 * @param {(element: T) => boolean} pred
 * @param {string | null} displayValue
 * @return {(element: T) => void}
 */
function displayUsing(pred, displayValue) {
    return ifElse(pred, display(displayValue), hide);
}

;// CONCATENATED MODULE: ./src/DOMReadyP.ts
/**
 * Returns a promise that resolves as soon as possible after the DOM content is loaded.
 * If the {@link https://developer.mozilla.org/en-US/docs/Web/API/Document/readyState `document.readyState`}
 * is `'interactive'` or `'complete'` at call-time, the returned promise resolves immediately, otherwise it resolves upon
 * the DOMContentLoaded event.
 *
 * @return {Promise<void>}
 */
function DOMReadyP() {
    return new Promise(function (resolve) {
        if (document.readyState !== 'loading') {
            resolve();
        }
        else {
            window.addEventListener('DOMContentLoaded', function () { return resolve(); });
        }
    });
}

;// CONCATENATED MODULE: ./src/getMeta.ts
function getMeta(name, transformer) {
    var element = document.querySelector("meta[name=\"" + name + "\"]");
    var rawContent = element === null || element === void 0 ? void 0 : element.getAttribute('content');
    if (element === null || rawContent == undefined) {
        return null;
    }
    if (typeof transformer === 'function') {
        return transformer(rawContent);
    }
    return rawContent;
}

;// CONCATENATED MODULE: ./src/innerText.ts
/**
 * Takes a string or `null`, and returns a function that takes `HTMLElement` elements. Sets `innerText` of
 * given elements to the given string, or to an empty string if given `null`.
 *
 * @example
 * ```typescript
 * // to set inner text
 * innerText('foo')(element)
 *
 * // to clear inner text
 * innerText(null)(element)
 *
 * // batch-clear contents:
 * declare const elements: HTMLElement[]
 * elements.forEach(innerText(null))
 * ```
 */
function innerText(text) {
    return function (element) {
        element.innerText = text || '';
    };
}

;// CONCATENATED MODULE: ./src/innerHTML.ts
/**
 * Takes an HTML string or `null`, and returns a function that takes `Element` objects. Sets `innerHTML` of
 * given elements to the given string, or to an empty string if given `null`.
 *
 * @example
 * ```typescript
 * // to set inner HTML
 * innerHTML('<span>foo</span>')(element)
 *
 * // to clear inner HTML
 * innerHTML(null)(element)
 *
 * // batch-clear contents:
 * declare const elements: Element[]
 * elements.forEach(innerHTML(null))
 * ```
 */
function innerHTML(html) {
    return function (element) {
        element.innerHTML = html || '';
    };
}

;// CONCATENATED MODULE: ./src/onDOMReady.ts

/**
 * Takes a callback that is executed as soon as possible after the DOM content is loaded.
 * If the {@link https://developer.mozilla.org/en-US/docs/Web/API/Document/readyState `document.readyState`}
 * is either `'interactive'` or `'complete'` at call-time, the callback is called immediately,
 * otherwise it is called upon the DOMContentLoaded event.
 *
 * @param {Function} fn
 * @return {Promise} A promise that resolves with the eventual return value of given callback.
 */
function onDOMReady(fn) {
    return DOMReadyP().then(fn);
}

;// CONCATENATED MODULE: ./src/windowLoadP.ts
/**
 * Returns a promise that resolves as soon as possible after the window is loaded.
 * If the {@link https://developer.mozilla.org/en-US/docs/Web/API/Document/readyState `document.readyState`}
 * is `'complete'` at call-time, the returned promise resolves immediately, otherwise it resolves upon
 * the window load event.
 *
 * @return {Promise<void>}
 */
function windowLoadP() {
    return new Promise(function (resolve) {
        if (document.readyState === 'complete') {
            resolve();
        }
        else {
            window.addEventListener('load', function () { return resolve(); });
        }
    });
}

;// CONCATENATED MODULE: ./src/onWindowLoad.ts

/**
 * Takes a callback that is executed as soon as possible after the window is loaded.
 * If the {@link https://developer.mozilla.org/en-US/docs/Web/API/Document/readyState `document.readyState`}
 * is `'complete'` at call-time, the callback is called immediately, otherwise it is called upon
 * the window load event.
 *
 * @param {Function} fn
 * @return {Promise} A promise that resolves with the eventual return value of given callback.
 */
function onWindowLoad(fn) {
    return windowLoadP().then(fn);
}

;// CONCATENATED MODULE: ./src/preventDefault.ts
/**
 * Takes events and calls their `.preventDefault()` method.
 *
 * @param event - The event instance to call the method on.
 * @example
 *
 * ```typescript
 * declare const event: Event
 * preventDefault(event)
 * ```
 */
function preventDefault(event) {
    event.preventDefault();
}

;// CONCATENATED MODULE: ./src/queryAll.ts
function queryAll(selector, scope) {
    if (scope === void 0) { scope = document; }
    return Array.prototype.slice.call(scope.querySelectorAll(selector));
}

;// CONCATENATED MODULE: ./src/queryAllWithin.ts

/**
 * Takes an element as scope for CSS selector queries. Returns a function that takes
 * selectors to query elements for within the set scope. The returned function finds
 * all elements matching given selector and returns them in an array.
 *
 * @example
 * ```typescript
 * declare const scope: HTMLElement
 * const queryFn = queryAllWithin(scope)
 *
 * // Automatically attempts to parse CSS selectors into an element type.
 * const headings = queryFn('h2.large-heading, h3.medium-heading') // HTMLHeadingElement[]
 *
 * // defaults to Element for element types - others: Element[]
 * const others = queryFn('.other')
 *
 * // takes an explicit element type for other selectors - buttons: HTMLButtonElement[]
 * const buttons = queryFn<HTMLButtonElement>('.button')
 *
 * // You can call queryWithin in one go, and still provide type arguments:
 * const buttons2 = queryAllWithin(scope)<HTMLButtonElement>('.button')
 * ```
 */
function queryAllWithin(scope) {
    return function (selector) { return queryAll(selector, scope); };
}

;// CONCATENATED MODULE: ./src/queryOne.ts
function queryOne(selector, scope) {
    if (scope === void 0) { scope = document; }
    return scope.querySelector(selector);
}

;// CONCATENATED MODULE: ./src/queryOneWithin.ts

/**
 * Takes an element as scope for CSS selector queries. Returns a function that takes
 * selectors to query elements for within the set scope. The returned function finds
 * the first element matching given selector and returns it. Returns `null` if no
 * matching element exists.
 *
 * @example
 * ```typescript
 * declare const scope: HTMLElement
 * const queryFn = queryOneWithin(scope)
 *
 * // Automatically attempts to parse CSS selectors into an element type.
 * const headings = queryFn('h2.large-heading') // HTMLHeadingElement | null
 *
 * // defaults to Element for element types - other: Element | null
 * const other = queryFn('.other')
 *
 * // takes an explicit element type for other selectors - button: HTMLButtonElement | null
 * const button = queryFn<HTMLButtonElement>('.button')
 *
 * // You can call queryOneWithin in one go, and still provide type arguments:
 * const button2 = queryOneWithin(scope)<HTMLButtonElement>('.button')
 * ```
 */
function queryOneWithin(scope) {
    return function (selector) { return queryOne(selector, scope); };
}

;// CONCATENATED MODULE: ./src/readDataset.ts
function readDataset(key, transform) {
    if (transform === void 0) { transform = function (x) { return x; }; }
    return function (element) {
        var value = element.dataset[key];
        return value === undefined ? undefined : transform(value);
    };
}

;// CONCATENATED MODULE: ./src/remove.ts
/**
 * Removes given element from the DOM if it's currently in it.
 * @param {Element} element
 */
function remove(element) {
    var _a;
    (_a = element.parentNode) === null || _a === void 0 ? void 0 : _a.removeChild(element);
}

;// CONCATENATED MODULE: ./src/removeClassesForMS.ts


/**
 * Removes classes from an element for a given amount of milliseconds.
 *
 * @param ms The amount of milliseconds to remove the classes for.
 * @param classes Rest parameter for one or multiple classes to remove.
 * @param element The element to remove the classes from.
 *
 * @example
 * ```typescript
 * declare const element: Element
 * removeClassesForMS(500, 'class-a', 'class-b') (element)
 * ```
 */
function removeClassesForMS(ms) {
    var classes = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        classes[_i - 1] = arguments[_i];
    }
    return function (element) {
        removeClasses.apply(void 0, classes)(element);
        window.setTimeout(function () { return addClasses.apply(void 0, classes)(element); }, ms);
    };
}

;// CONCATENATED MODULE: ./src/removeClassesForNFrames.ts



/**
 * Removes classes from an element for a given amount of animation frames.
 *
 * @param n The amount of animation frames to remove the classes for.
 * @param classes Rest parameter for one or multiple classes to temporarily remove.
 * @param element The element to remove the classes from.
 *
 * @example
 *
 * ```typescript
 * declare const element: Element
 * removeClassesForNFrames(10, 'class-a', 'class-b') (element)
 * ```
 */
function removeClassesForNFrames(n) {
    var classes = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        classes[_i - 1] = arguments[_i];
    }
    return function (element) {
        removeClasses.apply(void 0, classes)(element);
        deferFrames(n, function () { return addClasses.apply(void 0, classes)(element); });
    };
}

;// CONCATENATED MODULE: ./src/setMeta.ts
/**
 * Takes a string name and returns a new function that takes a string content, and
 * then updates the `<meta>` tag with the given name if it exists, or otherwise
 * creates a new one. The meta element to which the content value was set is returned
 * for reference.
 *
 * When a new element is created it will be appended to the end of `<head>`.
 *
 * @param name The value for the name attribute.
 * @param content The value for the content attribute.
 *
 * @example
 * ```typescript
 * const element = setMeta('foo')('bar')
 * ```
 * This updates or creates the following element
 * ```
 * <meta name="foo" content="bar">
 * ```
 */
function setMeta(name) {
    return function (content) {
        var element = document.querySelector("meta[name=\"" + name + "\"]");
        if (!element) {
            element = document.createElement('meta');
            element.name = name;
            document.head.appendChild(element);
        }
        element.content = content;
        return element;
    };
}

;// CONCATENATED MODULE: ./src/show.ts

/**
 * Shows the given element by unsetting any inline `style.display` value.
 * This is a specialisation of {@link display display()} that always unsets inline display.
 *
 * **Note**
 *
 * This function assumes that given elements are shown by default - ie. there's no CSS rule that has
 * set the element's display to 'none'.
 *
 * @example
 * ```typescript
 * declare const someElement: Element
 *
 * show(someElement)
 *
 * // This is equivalent to:
 * display(null) (someElement)
 * ```
 *
 * @param element The element to unset the inline display value for.
 */
function show(element) {
    display(null)(element);
}

;// CONCATENATED MODULE: ./src/showIf.ts


/**
 * Takes a `boolean` condition, and returns a function that takes elements. The returned function
 * will unset `style.display` onto a given element if the given condition is `true`. If the condition
 * is `false`, `style.display` is set to `'none'`.
 *
 * **Note**
 *
 * This function assumes that given elements are shown by default - ie. there's no CSS rule that has
 * set the element's display to 'none'.
 *
 * **Note**
 *
 * The condition is constant for all future calls to the returned function.
 * See {@link showUsing showUsing()} for cases where the boolean condition should
 * be determined for each element individually.
 *
 * @example
 * ```typescript
 * declare const checkboxes: HTMLInputElement[]
 * declare const myCondition: boolean
 *
 * // Unsets inline display to all checkboxes if myCondition is true
 * // Sets display: 'none' to all checkboxes otherwise
 * checkboxes.forEach(showIf(myCondition))
 * ```
 *
 * @param cond The condition for showing elements
 * @return {(element: HTMLElement) => void}
 */
function showIf(cond) {
    return cond ? show : hide;
}

;// CONCATENATED MODULE: ./src/showUsing.ts



/**
 * Takes a predicate function for elements and returns a function that takes elements
 * to conditionally show depending on the result of applying the predicate function to given elements.
 *
 * **Note**
 *
 * This function assumes that given elements are shown by default - ie. there's no CSS rule that has
 * set the element's display to 'none'.
 *
 * @example
 * ```typescript
 * declare const checkboxes: HTMLInputElement[]
 * const isChecked = (input: HTMLInputElement) => input.checked
 *
 * // Unsets inline display of all checkboxes that are checked
 * // Sets display: 'none' to all other checkboxes.
 * checkboxes.forEach(showUsing(isChecked))
 *
 * // This is equivalent to following usage of showIf():
 * checkboxes.forEach((checkbox) => showIf(isChecked(checkbox))(checkbox))
 * ```
 *
 * @param {(element: T) => boolean} pred
 * @return {(element: T) => void}
 */
function showUsing(pred) {
    return ifElse(pred, show, hide);
}

;// CONCATENATED MODULE: ./src/touchAll.ts
function touchAll(selectors, cb, scope) {
    if (scope === void 0) { scope = document; }
    var elements = [];
    for (var _i = 0, selectors_1 = selectors; _i < selectors_1.length; _i++) {
        var selector = selectors_1[_i];
        var el = scope.querySelector(selector);
        if (el === null) {
            return null;
        }
        elements.push(el);
    }
    return cb.apply(void 0, elements);
}

;// CONCATENATED MODULE: ./src/touchElement.ts
function touchElement(selector, callback, scope) {
    if (scope === void 0) { scope = document; }
    var element = scope.querySelector(selector);
    return element && callback(element);
}

;// CONCATENATED MODULE: ./src/touchElementP.ts

function touchElementP(selector, scope) {
    if (scope === void 0) { scope = document; }
    return new Promise(function (resolve) { return touchElement(selector, resolve, scope); });
}

;// CONCATENATED MODULE: ./src/touchAllP.ts

function touchAllP(selectors, scope) {
    if (scope === void 0) { scope = document; }
    return Promise.all(selectors.map(function (selector) { return touchElementP(selector, scope); }));
}

;// CONCATENATED MODULE: ./src/writeDataset.ts
/**
 * Write dataset values. Takes a key, and returns a new function that takes the value, which in turn
 * returns the last function that takes the element to write the key-value pair to.
 *
 * @param key The dataset property to write.
 * @param value The value to write to the property.
 * @param element An element upon which to perform the dataset update.
 *
 * @example
 *
 * ```typescript
 * declare const someElement: HTMLElement
 *
 * writeDataset('someKey') ('someValue') (someElement)
 * ```
 */
function writeDataset(key) {
    return function (value) { return function (element) { return void (element.dataset[key] = value); }; };
}

;// CONCATENATED MODULE: ./src/index.ts







































/******/ 	return __webpack_exports__;
/******/ })()
;
});
//# sourceMappingURL=lambda-dom.js.map